#ifndef PC_COMMANDS_H
#define PC_COMMANDS_H

#include "usb_keyboard.h"

// The different commands that can be sent back to the PC. For the sake of simplicity, the enum maps directly to the PowerDVD shortcut keys (0x80 is ORed for keys requiring a modifier).
enum pc_command_t {
	PC_COMMAND_NONE = 0,
	PC_COMMAND_1 = USB_KEYBOARD_KEY_1,
	PC_COMMAND_2 = USB_KEYBOARD_KEY_2,
	PC_COMMAND_3 = USB_KEYBOARD_KEY_3,
	PC_COMMAND_4 = USB_KEYBOARD_KEY_4,
	PC_COMMAND_5 = USB_KEYBOARD_KEY_5,
	PC_COMMAND_6 = USB_KEYBOARD_KEY_6,
	PC_COMMAND_7 = USB_KEYBOARD_KEY_7,
	PC_COMMAND_8 = USB_KEYBOARD_KEY_8,
	PC_COMMAND_9 = USB_KEYBOARD_KEY_9,
	PC_COMMAND_0 = USB_KEYBOARD_KEY_0,
	PC_COMMAND_NEXT_ANGLE = USB_KEYBOARD_KEY_A,
	PC_COMMAND_REVERSE = USB_KEYBOARD_KEY_B, // Repeat to increase speed
	PC_COMMAND_CAPTURE_FRAME = USB_KEYBOARD_KEY_C,
	PC_COMMAND_DISPLAY = USB_KEYBOARD_KEY_D, // Show information
	PC_COMMAND_STEP_BACKWARD = USB_KEYBOARD_KEY_E,
	PC_COMMAND_FORWARD = USB_KEYBOARD_KEY_F, // Repeat to increase speed
	PC_COMMAND_NEXT_AUDIO_STREAM = USB_KEYBOARD_KEY_H, // Or audio language
	PC_COMMAND_UPGRADE = USB_KEYBOARD_KEY_I,
	PC_COMMAND_ROOT_MENU = USB_KEYBOARD_KEY_J,
	PC_COMMAND_MENUS = USB_KEYBOARD_KEY_L, // Shows a context menu
	PC_COMMAND_ADD_BOOKMARK = USB_KEYBOARD_KEY_M, // Shows a context menu
	PC_COMMAND_NEXT = USB_KEYBOARD_KEY_N, 
	PC_COMMAND_OPEN = USB_KEYBOARD_KEY_O,  // Shows a context menu
	PC_COMMAND_PREVIOUS = USB_KEYBOARD_KEY_P, 
	PC_COMMAND_MUTE = USB_KEYBOARD_KEY_Q, 
	PC_COMMAND_STOP = USB_KEYBOARD_KEY_S, 
	PC_COMMAND_STEP_FORWARD = USB_KEYBOARD_KEY_T, 
	PC_COMMAND_NEXT_SUBTITLE = USB_KEYBOARD_KEY_U, 
	PC_COMMAND_SHUFFLE = USB_KEYBOARD_KEY_V, 
	PC_COMMAND_REPEAT_RANGE = USB_KEYBOARD_KEY_W,
	PC_COMMAND_TOGGLE_FULL_SCREEN = USB_KEYBOARD_KEY_Z,
	PC_COMMAND_ABOUT = USB_KEYBOARD_KEY_A | 0x80,
	PC_COMMAND_CONFIGURATION = USB_KEYBOARD_KEY_C | 0x80,
	PC_COMMAND_EJECT = USB_KEYBOARD_KEY_E | 0x80,
	PC_COMMAND_MINIMISE = USB_KEYBOARD_KEY_N | 0x80,
	PC_COMMAND_POPUP_MENU = USB_KEYBOARD_KEY_P | 0x80,
	PC_COMMAND_REPEAT = USB_KEYBOARD_KEY_R | 0x80,
	PC_COMMAND_DETACH_CONTROL_BAR = USB_KEYBOARD_KEY_T | 0x80,
	PC_COMMAND_EXIT = USB_KEYBOARD_KEY_X | 0x80,
	PC_COMMAND_RED = USB_KEYBOARD_KEY_F9,
	PC_COMMAND_GREEN = USB_KEYBOARD_KEY_F10,
	PC_COMMAND_YELLOW = USB_KEYBOARD_KEY_F11,
	PC_COMMAND_BLUE = USB_KEYBOARD_KEY_F12,
	PC_COMMAND_VOLUME_UP = USB_KEYBOARD_KEY_NUMPAD_PLUS,
	PC_COMMAND_VOLUME_DOWN = USB_KEYBOARD_KEY_NUMPAD_MINUS,
	PC_COMMAND_UP = USB_KEYBOARD_KEY_CURSOR_UP,
	PC_COMMAND_DOWN = USB_KEYBOARD_KEY_CURSOR_DOWN,
	PC_COMMAND_LEFT = USB_KEYBOARD_KEY_CURSOR_LEFT,
	PC_COMMAND_RIGHT = USB_KEYBOARD_KEY_CURSOR_RIGHT,
	PC_COMMAND_ACCEPT = USB_KEYBOARD_KEY_ENTER,
	PC_COMMAND_CANCEL = USB_KEYBOARD_KEY_ESCAPE,
	PC_COMMAND_PLAY = USB_KEYBOARD_KEY_ENTER,
	PC_COMMAND_PAUSE = USB_KEYBOARD_KEY_SPACE,
	PC_COMMAND_POWER = USB_KEYBOARD_KEY_F4 | 0x80,
	PC_COMMAND_MENU_AUTO, // Sends PC_COMMAND_POPUP_MENU in PC_COMMAND_MODE_BLU_RAY and PC_COMMAND_MENUS in PC_COMMAND_MODE_DVD
	PC_COMMAND_ROOT_MENU_AUTO, // Sends PC_COMMAND_POPUP_MENU in PC_COMMAND_MODE_BLU_RAY and PC_COMMAND_ROOT_MENU in PC_COMMAND_MODE_DVD
	PC_COMMAND_TOGGLE_MODE, // Switches between PC_COMMAND_MODE_BLU_RAY/PC_COMMAND_MODE_DVD
};

// Represents the different command mode sets.
enum pc_command_mode_t {
	PC_COMMAND_MODE_BLU_RAY,
	PC_COMMAND_MODE_DVD,
};

// References the current command mode.
extern enum pc_command_mode_t pc_command_mode;

// Sends a command to the PC.
void pc_command_send(enum pc_command_t command);

// Sends a command to the PC, repeating if allowed.
void pc_command_send_repeating(enum pc_command_t command, uint8_t repeat_count);

#endif